@@ -32,6 +32,8 @@ from gtk import \
     STOCK_CANCEL, RESPONSE_CANCEL, \
     STOCK_SAVE, RESPONSE_OK, STOCK_OPEN, DIALOG_MODAL, \
     MESSAGE_ERROR, BUTTONS_OK, \
+    BUTTONS_YES_NO, RESPONSE_YES, \
+    MESSAGE_INFO, \
     TreeView, ListStore, STOCK_ADD, STOCK_DELETE, VBox, HBox, Label, Button, \
     TreeViewColumn, CellRendererText, main as gtk_main, Window, main_quit, \
     CellRendererCombo, CellRendererText, Dialog, Calendar, Entry
@@ -80,12 +82,34 @@ def get_current_date_of_gtkcal(cal):
     (year, month, day) = cal.get_date()
     return date(year, month+1, day)
 
+def set_current_date_of_gtkcal(cal, date_to_set):
+    """Note, this doesn't supporess event handlers and calls
+       both select_month and select_day
+
+       date_to_set can be either a datetime.date or datetime.datetime
+    """
+    cal.select_month(date_to_set.month-1, date_to_set.year)
+    cal.select_day(date_to_set.day)
+
 def gtk_error_message(msg, parent=None):
+    gtk_ok_dialog(msg, parent, dia_type=MESSAGE_ERROR)
+
+def gtk_info_message(msg, parent=None):
+    gtk_ok_dialog(msg, parent, dia_type=MESSAGE_INFO)
+
+def gtk_ok_dialog(msg, parent=None, dia_type=MESSAGE_ERROR):
     error_dialog = MessageDialog(parent, DIALOG_MODAL, 
-                                 MESSAGE_ERROR, BUTTONS_OK, msg)
+                                 dia_type, BUTTONS_OK, msg)
     error_dialog.run()
     error_dialog.destroy()
 
+def gtk_yes_no_dialog(msg, parent=None, dia_type=MESSAGE_ERROR):
+    yes_no_dialog = MessageDialog(parent, DIALOG_MODAL, 
+                                  dia_type, BUTTONS_YES_NO, msg)
+    result = (RESPONSE_YES == yes_no_dialog.run())
+    yes_no_dialog.destroy()
+    return result
+
 def start_stock_button(stock_code):
     but = Button()
     but.set_property('use-stock', True)
@@ -549,6 +573,8 @@ def test_prog_list_changed(*args):
 def main():
     print 'answer', input_entry_dialog("who what?", 'edit me')
 
+    gtk_info_message("hi there missy")
+
     w = Window()
     w.resize(200, 200)
     w.connect( "delete-event", main_quit )
