@@ -32,12 +32,10 @@ from ZODB.FileStorage import FileStorage
 from ZODB.config import databaseFromURL
 
 # bo-keep
-from bokeep.util import \
-    ends_with_commit, FunctionAndDataDrivenStateMachine, \
-    state_machine_do_nothing, state_machine_always_true
+from bokeep.util import FunctionAndDataDrivenStateMachine, null_function
 from bokeep.config import DEFAULT_BOOKS_FILESTORAGE_FILE,\
     ZODB_CONFIG_FILESTORAGE, ZODB_CONFIG_ZCONFIG
-from bokeep.book import BoKeepBookSet, BackendPluginImportError, PluginImportError
+from bokeep.book import BoKeepBookSet, BackendPluginImportError, FrontendPluginImportError
 
 # possible actions
 (DB_ENTRY_CHANGE, DB_PATH_CHANGE, BOOK_CHANGE, BACKEND_PLUGIN_CHANGE) = \
@@ -49,22 +47,23 @@ from bokeep.book import BoKeepBookSet, BackendPluginImportError, PluginImportErr
 class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
     NUM_STATES = 3
     (
-        # There is no working database selected
+        # There is no working database selected.
         NO_DATABASE,
-        # There is a working database, but no book selected
+        # There is a working database, but no book selected.
         NO_BOOK,
-        # There is a book selected on a working database
+        # There is a book selected on a working database.
         BOOK_SELECTED,
-        ) = range(NUM_STATES)
+    ) = range(NUM_STATES)
 
-    def __init__(self, db_error_msg=None):
+    def __init__(self, db_error_msg=None, call_for_new_plugins=null_function):
         FunctionAndDataDrivenStateMachine.__init__(
             self,
             data=(None, None, None), # DB_PATH, BOOKSET, BOOK
             initial_state=BoKeepConfigGuiState.NO_DATABASE)
         self.db_error_msg = db_error_msg
         self.book_liststore = ListStore(str)
-        self.plugin_liststore = ListStore(str, bool)
+        self.frontend_plugin_liststore = ListStore(str, bool)
+        self.call_for_new_plugins = call_for_new_plugins
         self.run_until_steady_state()
         assert(self.state == BoKeepConfigGuiState.NO_DATABASE)
 
@@ -118,7 +117,6 @@ class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
         
         return self._v_table_cache
 
-    
     def action_allowed(self, action):
         if not hasattr(self, '_v_action_allowed_table'):
             self._v_action_allowed_table = {
@@ -205,7 +203,7 @@ class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
         return (self._v_action_arg[0], self._v_action_arg[1], None, None)
 
     def __handle_book_change_load_plugin_list(self, next_state):
-        self.plugin_liststore.clear()
+        self.frontend_plugin_liststore.clear()
         new_book_name = self._v_action_arg
         if new_book_name == None:
             return (self.data[DB_PATH], self.data[DB_ACCESS_METHOD],
@@ -213,16 +211,16 @@ class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
         if not self.data[BOOKSET].has_book(new_book_name):
             self.data[BOOKSET].add_book(new_book_name)
         new_book = self.data[BOOKSET].get_book(new_book_name)
-        # construct plugin_liststore from book
-        for plugin_name in new_book.get_modules().iterkeys():
-            self.plugin_liststore.append((plugin_name, True))
+        # construct frontend_plugin_liststore from book
+        for plugin_name in new_book.get_frontend_plugins().iterkeys():
+            self.frontend_plugin_liststore.append((plugin_name, True))
         for plugin_name in new_book.disabled_modules.iterkeys():
-            self.plugin_liststore.append((plugin_name, False))
+            self.frontend_plugin_liststore.append((plugin_name, False))
         return (self.data[DB_PATH], self.data[DB_ACCESS_METHOD],
                 self.data[BOOKSET], new_book )
 
     def __clear_plugin_list(self, next_state = None):
-        self.plugin_liststore.clear()
+        self.frontend_plugin_liststore.clear()
         return self.data
 
     def __apply_plugin_changes_and_clear(self, next_state):
@@ -234,14 +232,14 @@ class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
             self.__clear_plugin_list()
             return self.__clear_book_list(next_state)
         else:
-            raise PluginImportError(modules_not_found)
+            raise FrontendPluginImportError(modules_not_found)
 
     def __apply_plugin_changes_and_reset_plugin_list(self, next_state):
         modules_not_found = self.__apply_plugin_changes()
         if modules_not_found == []:
             return self.__handle_book_change_load_plugin_list(next_state)
         else:
-            raise PluginImportError(modules_not_found)
+            raise FrontendPluginImportError(modules_not_found)
 
     def __record_backend_plugin(self, next_state):
         self._v_backend_plugin = self._v_action_arg
@@ -251,34 +249,48 @@ class BoKeepConfigGuiState(FunctionAndDataDrivenStateMachine):
 
     def __apply_plugin_changes(self):
         not_found_modules = []
-        for plugin_name, plugin_enabled in self.plugin_liststore:
+        for plugin_name, plugin_enabled in self.frontend_plugin_liststore:
             # fix any plugins that are marked enabled, but not
             if plugin_enabled and \
-                    not self.data[BOOK].has_module_enabled(plugin_name):
+                    not self.data[BOOK].has_enabled_frontend_plugin(plugin_name):
                 # if such a plugin isn't disabled, it has to be added
                 try:
-                    if not self.data[BOOK].has_module_disabled(plugin_name):
-                        self.data[BOOK].add_module(plugin_name)
+                    if not self.data[BOOK].has_disabled_frontend_plugin(plugin_name):
+                        self.data[BOOK].add_frontend_plugin(plugin_name)
                     # now we can enable it
-                    self.data[BOOK].enable_module(plugin_name)
-                except PluginImportError:
+                    self.data[BOOK].enable_frontend_plugin(plugin_name)
+
+                    # Configure the newly added frontend plugins.
+                    book = self.data[BOOK]
+                    FRONTEND = False
+                    frontend_plugin = \
+                        book.get_frontend_plugin(plugin_name)
+                    self.call_for_new_plugins(book, FRONTEND, frontend_plugin)
+
+                except FrontendPluginImportError:
                     not_found_modules.append(plugin_name)
             # fix any plugins that are marked disabled, but aren't
             elif not plugin_enabled and \
-                    not self.data[BOOK].has_module_disabled(plugin_name):
+                    not self.data[BOOK].has_disabled_frontend_plugin(plugin_name):
                 # such a plugin might be enabled and just need to be disabled
-                if self.data[BOOK].has_module_enabled(plugin_name):
-                    self.data[BOOK].disable_module(plugin_name)
+                if self.data[BOOK].has_enabled_frontend_plugin(plugin_name):
+                    self.data[BOOK].disable_frontend_plugin(plugin_name)
                 # or it may have never been added
                 else:
                     try:
-                        self.data[BOOK].add_module(plugin_name)        
-                    except PluginImportError:
+                        self.data[BOOK].add_frontend_plugin(plugin_name)
+                    except FrontendPluginImportError:
                         not_found_modules.append(plugin_name)
 
         if self.data[BOOK] != None and hasattr(self, '_v_backend_plugin'):
             try:
-                self.data[BOOK].set_backend_module(self._v_backend_plugin)
+                self.data[BOOK].set_backend_plugin(self._v_backend_plugin)
+                
+                # Configure the newly added backend plugin.
+                book = self.data[BOOK]
+                BACKEND = True
+                backend_plugin = book.get_backend_plugin()
+                self.call_for_new_plugins(book, BACKEND, backend_plugin)
             except BackendPluginImportError:
                 not_found_modules.append(self._v_backend_plugin)
             finally:
