@@ -1,4 +1,4 @@
-# Copyright (C) 2011  ParIT Worker Co-operative, Ltd <paritinfo@parit.ca>
+# Copyright (C) 2011-2012 ParIT Worker Co-operative, Ltd <paritinfo@parit.ca>
 #
 # This file is part of Bo-Keep.
 #
@@ -28,14 +28,17 @@ from persistent.mapping import PersistentMapping
 # gtk imports
 from gtk import \
     VBox, HBox, Window, Button, STOCK_GO_FORWARD, STOCK_GO_BACK, Label, \
-    Entry, Calendar
+    Entry, Calendar, CheckButton, \
+    ScrolledWindow, Viewport, POLICY_AUTOMATIC, POLICY_NEVER
 
 # bokeep imports
 from bokeep.book_transaction import \
     Transaction, FinancialTransaction, make_fin_line, \
     BoKeepTransactionNotMappableToFinancialTransaction
-from bokeep.gtkutil import input_entry_dialog, get_current_date_of_gtkcal, \
-    gtk_error_message
+from bokeep.gtkutil import \
+    (input_entry_dialog, gtk_error_message,
+     get_current_date_of_gtkcal, set_current_date_of_gtkcal, )
+     
 from bokeep.gui.gladesupport.glade_util import \
     load_glade_file_get_widgets_and_connect_signals
 from bokeep.safe_config_based_plugin_support import \
@@ -191,6 +194,20 @@ def config_valid(config):
 
 GLADE_FILE, TOP_WIDGET = range(2)
 
+def make_widget_changed_func(get_state_func):
+    def widget_changed(self, widget, *args):
+        config = self.plugin.get_configuration(allow_reload=False)
+        widget_key = ( (config.pages[self.current_page]),
+                       widget.get_name() )
+        self.trans.update_widget_state(
+            widget_key, get_state_func(widget) )
+        self.change_register_function()
+        self.update_auto_labels()
+    return widget_changed
+
+def get_state_of_checkbutton(checkbutton):
+    return checkbutton.get_active()
+
 class multipage_glade_editor(object):
     def __init__(self,
                  trans, transid, plugin, gui_parent, change_register_function,
@@ -252,7 +269,34 @@ class multipage_glade_editor(object):
                 self.change_register_function()
 
             self.page_label = Label("")
-            self.mainvbox.pack_start(self.page_label)
+            (x_align, y_align) = self.page_label.get_alignment()
+            self.page_label.set_alignment(0.0, y_align)
+            self.mainvbox.pack_start(self.page_label, expand=False)
+
+            # establish maincontainer, which is where the actual glade
+            # pages are put by attach_current_page
+            #
+            # The order of placement here is important, we place this
+            # after page_label has already been added to main
+            # and we also need to do this prior to attach_current_page
+            # being called, as it depends on self.maincontainer being
+            # there
+            #
+            # when we're in headless mode the maincontainer can just be
+            # the mainvbox itself
+            #
+            # but, outside headless mode we save screen real-estate and
+            # place a scrolled window (which becomes the maincontainer)
+            # inside the mainvbox and the glade by glade pages end up
+            # in there instead (again, in attach_current_page)
+            if display_mode in HEADLESS_MODES:
+                self.maincontainer = self.mainvbox
+            else:
+                self.maincontainer = Viewport()
+                sw = ScrolledWindow()
+                sw.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
+                sw.add( self.maincontainer)
+                self.mainvbox.pack_start(sw)
 
             self.glade_pages = [
                 self.__setup_page(glade_file, top_glade_element)
@@ -305,42 +349,68 @@ class multipage_glade_editor(object):
         return widget_dict
 
     def __setup_auto_widgets(self):
+        # go through each page
         for key, widget_dict in self.glade_pages_by_ident_index.iteritems():
+            # go through each widget
             for widget_name, widget in widget_dict.iteritems():
                 widget_key = (key, widget_name)
-                for cls, func in (
-                    (Entry, self.__setup_auto_entry),
-                    (Calendar, self.__setup_auto_calendar), ):
+
+                # determine if the current widget is one that we can take
+                # care of automatically saving, we do this with a linear
+                # search through a table of eligible types,
+                # where the first element of each entry is Widget class
+                #
+                # Once we have a match do one of the following
+                #  * Change the widget from the existing stored stage
+                #  * Establish new state from some default
+                # The next two entries in the table
+                # (change_widget_from_state, new_state_from_widget)
+                # provide functions to do this
+                #
+                # Lastly, we establish event handlers for this widget using
+                # the last element in the table
+                for (cls,
+                     change_widget_from_state, new_state_from_widget,
+                     establish_event_handlers) in ( # start table
+
+                    (Entry,
+                     lambda w, wk: w.set_text(self.trans.get_widget_state(wk)),
+                     lambda w: '',
+                     lambda w: w.connect("changed", self.entry_changed),
+                     ), # Entry
+
+                    (Calendar,
+                     self.__change_calendar_from_saved_version,
+                     get_current_date_of_gtkcal,
+                     lambda w: w.connect( "day_selected",
+                                          self.calendar_changed ), 
+                     ), # Calendar
+
+                    (CheckButton,
+                     lambda w, wk:
+                         w.set_active(self.trans.get_widget_state(wk)),
+                     get_state_of_checkbutton,
+                     lambda w: w.connect("toggled", self.checkbutton_changed),
+                     ), # CheckButton
+
+                    ): # end of table and for declartion
+
+                    # does the widget match the type in the current table entry?
                     if isinstance(widget, cls):
-                        func(widget, widget_key)
 
-    def __setup_auto_entry(self, widget, widget_key):
-        # important to do the initial set prior to setting up
-        # the event handler for changed events
-        if self.trans.has_widget_state( widget_key ):
-            widget.set_text(
-                self.trans.get_widget_state( widget_key ) )
-        else:
-            self.trans.update_widget_state(widget_key,
-                                           '')
-        widget.connect( "changed", self.entry_changed )            
+                        # use the three remaining functions in the table
+                        # as appropriate
+                        if self.trans.has_widget_state( widget_key ):
+                            change_widget_from_state(widget, widget_key)
+                        else:
+                            self.trans.update_widget_state(
+                                widget_key,
+                                new_state_from_widget(widget) )
+                        establish_event_handlers(widget)
 
-    def __setup_auto_calendar(self, widget, widget_key):
-        # FIXME, copy-pasted code from __setup_auto_entry, common parts
-        # should be commonized... either in __setup_auto_widgets or with
-        # a decorator
-        # 
-        # important to do the initial set prior to setting up
-        # the event handler for changed events
-        if self.trans.has_widget_state( widget_key ):
-            date_to_set = self.trans.get_widget_state( widget_key )
-            widget.select_month(date_to_set.month-1, date_to_set.year)
-            widget.select_day(date_to_set.day)
-        else:
-            self.trans.update_widget_state(widget_key,
-                                           get_current_date_of_gtkcal(widget) )
-        widget.connect( "day_selected", self.calendar_changed )            
-        
+    def __change_calendar_from_saved_version(self, widget, widget_key):
+        set_current_date_of_gtkcal(widget, 
+                                   self.trans.get_widget_state( widget_key ) )
 
     def attach_current_page(self):
         config = self.plugin.get_configuration(allow_reload=False)
@@ -349,7 +419,7 @@ class multipage_glade_editor(object):
             config.pages[self.current_page][TOP_WIDGET] ]
         self.current_top_vbox = self.current_window.child
         self.current_top_vbox.reparent(
-            self.mainvbox)
+            self.maincontainer)
         self.page_label.set_text( "page %s of %s" %( self.current_page + 1,
                                                      len(config.pages) ) )
         self.update_auto_labels()
@@ -427,25 +497,9 @@ class multipage_glade_editor(object):
             # that's what we mean by post
             config.page_post_change_config_hooks(self.trans, old_page, new_page)
 
-    def entry_changed(self, entry, *args):
-        config = self.plugin.get_configuration(allow_reload=False)
-        widget_key = ( (config.pages[self.current_page]), entry.get_name() )
-        self.trans.update_widget_state(
-            widget_key, entry.get_text() )
-        self.change_register_function()
-        self.update_auto_labels()
-
-    def calendar_changed(self, calendar, *args):
-        # woah, see the commonality with entry_changed, perhaps it's time
-        # to do some decorating no?
-        print("cal changed")
-        config = self.plugin.get_configuration(allow_reload=False)
-        widget_key = ( (config.pages[self.current_page]), calendar.get_name() )
-        self.trans.update_widget_state(
-            widget_key, get_current_date_of_gtkcal(calendar) )
-        self.change_register_function()
-        self.update_auto_labels()        
-        
+    entry_changed = make_widget_changed_func(lambda w: w.get_text() )
+    calendar_changed = make_widget_changed_func(get_current_date_of_gtkcal)
+    checkbutton_changed = make_widget_changed_func(get_state_of_checkbutton)
 
     def update_auto_labels(self):
         config = self.plugin.get_configuration(allow_reload=False)
